import type {NewTaskData, Task} from './task/task.model';
import {Injectable} from '@angular/core';

@Injectable({providedIn: 'root'})
export class TasksService {
  private tasks: Task[] = [];

  constructor() {
    const tasks = localStorage.getItem('tasks');

    if (tasks) {
      this.tasks = JSON.parse(tasks);
    }
  }

  getUserTasks(userId: string) {
    return this.tasks.filter((task) => task.userId === userId);
  }

  addTaskFor(userId: string, taskData: NewTaskData) {
    let nextTaskId = this.tasks.length + 1;
    let taskId = 't' + (nextTaskId).toString();

    this.tasks.push({
      id: taskId,
      userId: userId,
      title: taskData.title,
      summary: taskData.summary,
      dueDate: taskData.date,
    });

    this.saveTasks()
  }

  removeTask(taskId: string) {
    this.tasks = this.tasks.filter((task) => task.id !== taskId);

    this.saveTasks()
  }

  private saveTasks() {
    localStorage.setItem('tasks', JSON.stringify(this.tasks));
  }
}
